Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type KeyOptions ¶
type KeyOptions struct {
PublicKeyPaths []string
}
func (*KeyOptions) AddFlags ¶
func (ko *KeyOptions) AddFlags(cmd *cobra.Command)
AddFlags adds the options flags to a command
func (*KeyOptions) ParseKeys ¶
func (ko *KeyOptions) ParseKeys() ([]key.PublicKeyProvider, error)
ParseKeys parses the key files and returns a slice of public key providers.
func (*KeyOptions) Verify ¶
func (ko *KeyOptions) Verify() error
Verify checks the options. Key files are verified to check if they exist
type OptionsSet ¶
OptionsSet is an interface that defines the functions options set need to implement to make them reusable.
Click to show internal directories.
Click to hide internal directories.